@@ -5,3 +5,11 @@ def double(array_array_array):
             mody.append(array)
 
     return mody
+
+
+def single(one):
+    array = [one]
+    return array
+
+
+print(single(1))
